package org.pfsw.oidc;

import static org.junit.Assert.*;

import java.util.List;

import org.junit.Test;
import org.pfsw.oidc.testhelper.UnitTestHelper;
import org.pfsw.text.json.JsonObject;

public class OpenIdProviderMetadataTest
{
  @Test
  public void test_getters_1()
  {
    JsonObject jsonObject = UnitTestHelper.readJsonObjectFrom("op-metadata-1.json");
    OpenIdProviderMetadata metadata;
    List<String> strings;
    
    metadata = new OpenIdProviderMetadata(jsonObject);
    assertEquals("https://idp1.galaxy.vdc:8443/auth/realms/coma", metadata.getIssuer());
    assertEquals("https://idp1.galaxy.vdc:8443/auth/realms/coma/protocol/openid-connect/auth", metadata.getAuthorizationEndpoint());
    assertNull(metadata.getClaimsParameterSupported());
    assertNull(metadata.getStringField("unknown"));
    assertNull(metadata.getStringsField("unknown"));
    assertNull(metadata.getBooleanField("unknown"));
    strings = metadata.getGrantTypesSupported();
    assertTrue(strings.contains("authorization_code"));
    assertTrue(strings.contains("implicit"));
    assertFalse(strings.contains("profile"));
    assertTrue(strings.contains("refresh_token"));
  }

  @Test
  public void test_getters_2()
  {
    JsonObject jsonObject = UnitTestHelper.readJsonObjectFrom("op-metadata-2.json");
    OpenIdProviderMetadata metadata;
    List<String> strings;
    
    metadata = new OpenIdProviderMetadata(jsonObject);
    assertEquals("https://c2id.com", metadata.getIssuer());
    assertEquals("https://c2id.com/login", metadata.getAuthorizationEndpoint());
    assertEquals("https://c2id.com/token", metadata.getTokenEndpoint());
    assertEquals("https://c2id.com/token/introspect", metadata.getStringField("introspection_endpoint"));
    assertEquals("https://demo.c2id.com/c2id/jwks.json", metadata.getJsonWebKeySetURI());
    assertTrue(metadata.getClaimsParameterSupported());
    assertNull(metadata.getStringField("unknown"));
    assertNull(metadata.getStringsField("unknown"));
    assertNull(metadata.getBooleanField("unknown"));
    strings = metadata.getScopesSupported();
    assertTrue(strings.contains("openid"));
    assertTrue(strings.contains("email"));
    assertTrue(strings.contains("profile"));
    assertTrue(strings.contains("offline_access"));
  }
}