package org.pfsw.oidc.testhelper;

import java.io.BufferedReader;
import java.io.Closeable;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.StringWriter;
import java.net.URL;
import java.nio.charset.Charset;

import org.pfsw.bif.text.ICharsets;
import org.pfsw.text.json.JsonObject;
import org.pfsw.text.json.JsonParseException;
import org.pfsw.text.json.SimpleJsonParser;

public class UnitTestHelper
{
  public static final String BASE_TESTDATA_DIR = System.getProperty("testdata.dir", "./src/test/testdata/");
  public static final String TESTDATA_DIR = BASE_TESTDATA_DIR + "pf-oidc/";
  public static final Charset DEFAULT_CHARSET = ICharsets.UTF_8;
  public static final String LINE_SEPARATOR = System.getProperty("line.separator");

  public static JsonObject readJsonObjectFrom(String filename)
  {
    String text;
    SimpleJsonParser parser;
    JsonObject jsonObject;

    text = UnitTestHelper.readTestData(filename);
    parser = new SimpleJsonParser();
    try
    {
      jsonObject = (JsonObject)parser.parse(text);
    }
    catch (JsonParseException ex)
    {
      throw new RuntimeException("Error parsing JSON: ", ex);
    }
    return jsonObject;
  }
  
  @SuppressWarnings("resource")
  public static String readTestData(String filename)
  {
    InputStream inStream;
    StringWriter writer;
    BufferedReader reader = null;
    String line;
    int counter = 0;
    URL url;
    String fileLocation = "?" + filename;

    writer = new StringWriter(1024);
    try
    {
      fileLocation = TESTDATA_DIR + filename; 
      if (TESTDATA_DIR.startsWith("jar:"))
      {
        url = new URL(fileLocation);
        inStream = url.openStream();
      }
      else
      {
        inStream = new FileInputStream(fileLocation);
      }
      reader = new BufferedReader(new InputStreamReader(inStream, DEFAULT_CHARSET));
      while (reader.ready())
      {
        line = reader.readLine();
        if (line == null)
        {
          break;
        }
        if (counter > 0)
        {
          writer.write(LINE_SEPARATOR);
        }
        writer.write(line);
        counter++;
      }
    }
    catch (IOException e)
    {
      throw new RuntimeException("Failed readTestData: " + fileLocation, e);
    }
    finally
    {
      close(reader);
      close(writer);
    }
    return writer.toString();
  }

  /**
   * Close the given closeable ignoring any exception and checking for null before closing.
   * Returns true, if the object was closed successfully, false otherwise.
   */
  public static boolean close(Closeable closeable)
  {
    if (closeable == null)
    {
      return false;
    }
    try
    {
      closeable.close();
      return true;
    }
    catch (@SuppressWarnings("unused") IOException e)
    {
      return false;
    }
  }
  // Not supposed to be instantiated
  private UnitTestHelper()
  {
    super();
  }
}
